@@ -43,10 +43,7 @@ def invalidate_zone(zone):
         try:
             cache.incr(key)
         except ValueError:
-
-            # DummyCache will always raise a ValueError so ignore that one
-            if not isinstance(cache, DummyCache):
-                raise
+            pass
 
 
 def make_zone_key(key, version=None, zone=None):
